==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/es-MX/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmar eliminación masiva de activos',
    'bulk_restore'      => 'Confirmar recuperación masiva de activos', 
  'bulk_delete_help'	=> 'Revise a continuación los activos para eliminación masiva. Una vez eliminados, estos activos se pueden restaurar, pero ya no estarán asociados a ningún usuario al que estén asignados actualmente.',
  'bulk_restore_help'	=> 'Revisar los activos para la restauración en masa a continuación. Una vez restaurados, estos activos no estarán asociados con los usuarios a los que fueron asignados anteriormente.',
  'bulk_delete_warn'	=> 'Va a eliminar :asset_count activos.',
  'bulk_restore_warn'	=> 'Está a punto de restaurar :asset_count activos.',
    'bulk_update'		=> 'Actualización masiva de activos',
    'bulk_update_help'	=> 'Este formulario le permite actualizar varios activos a la vez. Complete solo los campos que necesite modificar. Los campos que se dejen en blanco no se modificarán. ',
    'bulk_update_warn'	=> 'Está a punto de editar las propiedades de un solo activo.|Está a punto de editar las propiedades de :asset_count activos.',
    'bulk_update_with_custom_field' => 'Tenga en cuenta que los activos corresponden a :asset_model_count tipos diferentes de modelos.',
    'bulk_update_model_prefix' => 'En modelos', 
    'bulk_update_custom_field_unique' => 'Este es un campo único y no puede ser editado de forma masiva.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de ingreso',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio de compra',
    'create'			=> 'Crear activo',
    'date'				=> 'Fecha de compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación predeterminada',
    'default_location_phone' => 'Teléfono de ubicación predeterminada',
    'eol_date'			=> 'Fecha fin de soporte (EOL)',
    'eol_rate'			=> 'Tasa fin de soporte (EOL)',
    'expected_checkin'  => 'Fecha esperada de devolución',
    'expires'			=> 'Vence',
    'fully_depreciated'	=> 'Totalmente amortizado',
    'help_checkout'		=> 'Si desea asignar este equipo inmediatamente, seleccione "Listo para asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre del activo',
    'notes'				=> 'Notas',
    'order'				=> 'Número de orden',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este elemento',
    'redirect_to_all'   => 'Regresar a :type',
    'redirect_to_type'   => 'Ir a :type',
    'redirect_to_checked_out_to'   => 'Ir a elementos asignados',
    'select_statustype'	=> 'Seleccione un tipo de estado',
    'serial'			=> 'Número de serie',
    'status'			=> 'Estado',
    'tag'				=> 'Placa del activo',
    'update'			=> 'Actualizar activo',
    'warranty'			=> 'Garantía',
        'warranty_expires'		=> 'Vencimiento de la garantía',
    'years'				=> 'años',
    'asset_location' => 'Actualizar ubicación del activo',
    'asset_location_update_default_current' => 'Actualizar ubicación predeterminada y ubicación actual',
    'asset_location_update_default' => 'Actualizar sólo la ubicación predeterminada',
    'asset_location_update_actual' => 'Actualizar sólo la ubicación actual',
    'asset_not_deployable' => 'Ese estado de activos es no utilizable. Este activo no puede ser asignado.',
    'asset_not_deployable_checkin' => 'Ese estado del activo no es utilizable. El uso de esta etiqueta de estado ingresará el activo.',
    'asset_deployable' => 'El estado indica que es utilizable. Este activo puede ser asignado.',
    'processing_spinner' => 'Procesando... (Esto puede tomar un poco de tiempo en archivos grandes)',
    'optional_infos'  => 'Información opcional',
    'order_details'   => 'Información relacionada con el pedido'
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/es-MX/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmar eliminación masiva de activos',
    'bulk_restore'      => 'Confirmar recuperación masiva de activos', 
  'bulk_delete_help'	=> 'Revise a continuación los activos para eliminación masiva. Una vez eliminados, estos activos se pueden restaurar, pero ya no estarán asociados a ningún usuario al que estén asignados actualmente.',
  'bulk_restore_help'	=> 'Revisar los activos para la restauración en masa a continuación. Una vez restaurados, estos activos no estarán asociados con los usuarios a los que fueron asignados anteriormente.',
  'bulk_delete_warn'	=> 'Va a eliminar :asset_count activos.',
  'bulk_restore_warn'	=> 'Está a punto de restaurar :asset_count activos.',
    'bulk_update'		=> 'Actualización masiva de activos',
    'bulk_update_help'	=> 'Este formulario le permite actualizar varios activos a la vez. Complete solo los campos que necesite modificar. Los campos que se dejen en blanco no se modificarán. ',
    'bulk_update_warn'	=> 'Está a punto de editar las propiedades de un solo activo.|Está a punto de editar las propiedades de :asset_count activos.',
    'bulk_update_with_custom_field' => 'Tenga en cuenta que los activos corresponden a :asset_model_count tipos diferentes de modelos.',
    'bulk_update_model_prefix' => 'En modelos', 
    'bulk_update_custom_field_unique' => 'Este es un campo único y no puede ser editado de forma masiva.',
    'checkedout_to'		=> 'Asignado a',
    'checkout_date'		=> 'Fecha de asignación',
    'checkin_date'		=> 'Fecha de ingreso',
    'checkout_to'		=> 'Asignar a',
    'cost'				=> 'Precio de compra',
    'create'			=> 'Crear activo',
    'date'				=> 'Fecha de compra',
    'depreciation'	    => 'Depreciación',
    'depreciates_on'	=> 'Se deprecia en',
    'default_location'	=> 'Ubicación predeterminada',
    'default_location_phone' => 'Teléfono de ubicación predeterminada',
    'eol_date'			=> 'Fecha fin de soporte (EOL)',
    'eol_rate'			=> 'Tasa fin de soporte (EOL)',
    'expected_checkin'  => 'Fecha esperada de devolución',
    'expires'			=> 'Vence',
    'fully_depreciated'	=> 'Totalmente amortizado',
    'help_checkout'		=> 'Si desea asignar este equipo inmediatamente, seleccione "Listo para asignar" de la lista de estados de arriba. ',
    'mac_address'		=> 'Dirección MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nombre del activo',
    'notes'				=> 'Notas',
    'order'				=> 'Número de orden',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Los usuarios pueden solicitar este elemento',
    'redirect_to_all'   => 'Regresar a :type',
    'redirect_to_type'   => 'Ir a :type',
    'redirect_to_checked_out_to'   => 'Ir a elementos asignados',
    'select_statustype'	=> 'Seleccione un tipo de estado',
    'serial'			=> 'Número de serie',
    'status'			=> 'Estado',
    'tag'				=> 'Placa del activo',
    'update'			=> 'Actualizar activo',
    'warranty'			=> 'Garantía',
        'warranty_expires'		=> 'Vencimiento de la garantía',
    'years'				=> 'años',
    'asset_location' => 'Actualizar ubicación del activo',
    'asset_location_update_default_current' => 'Actualizar ubicación predeterminada y ubicación actual',
    'asset_location_update_default' => 'Actualizar sólo la ubicación predeterminada',
    'asset_location_update_actual' => 'Actualizar sólo la ubicación actual',
    'asset_not_deployable' => 'Ese estado de activos es no utilizable. Este activo no puede ser asignado.',
    'asset_not_deployable_checkin' => 'Ese estado del activo no es utilizable. El uso de esta etiqueta de estado ingresará el activo.',
    'asset_deployable' => 'El estado indica que es utilizable. Este activo puede ser asignado.',
    'processing_spinner' => 'Procesando... (Esto puede tomar un poco de tiempo en archivos grandes)',
    'optional_infos'  => 'Información opcional',
    'order_details'   => 'Información relacionada con el pedido',
    'calc_eol'    => 'Si deja nula la fecha EOL, utilice el cálculo automático basado en la fecha de compra y la frecuencia de EOL.',
];
